diff --git a/config/vufind/KohaRest.ini b/config/vufind/KohaILSDI.ini
similarity index 100%
rename from config/vufind/KohaRest.ini
rename to config/vufind/KohaILSDI.ini
diff --git a/module/VuFind/config/module.config.php b/module/VuFind/config/module.config.php
index 24452718e77fea4ce5e7e00a29a2ac25ab7a77a1..ee4690ac927257030b9b7b0808fd1c92410e0c38 100644
--- a/module/VuFind/config/module.config.php
+++ b/module/VuFind/config/module.config.php
@@ -387,7 +387,7 @@ $config = [
                     'horizonxmlapi' => 'VuFind\ILS\Driver\Factory::getHorizonXMLAPI',
                     'multibackend' => 'VuFind\ILS\Driver\Factory::getMultiBackend',
                     'noils' => 'VuFind\ILS\Driver\Factory::getNoILS',
-                    'koharest' => 'VuFind\ILS\Driver\Factory::getKohaRest',
+                    'kohailsdi' => 'VuFind\ILS\Driver\Factory::getKohaILSDI',
                     'unicorn' => 'VuFind\ILS\Driver\Factory::getUnicorn',
                     'voyager' => 'VuFind\ILS\Driver\Factory::getVoyager',
                     'voyagerrestful' => 'VuFind\ILS\Driver\Factory::getVoyagerRestful',
diff --git a/module/VuFind/src/VuFind/ILS/Driver/Factory.php b/module/VuFind/src/VuFind/ILS/Driver/Factory.php
index 8e23a35120ee1763a6c3efd31fef790393387035..f3e14a8ac2c1b2d5a98ae4008d1af098ff02402f 100644
--- a/module/VuFind/src/VuFind/ILS/Driver/Factory.php
+++ b/module/VuFind/src/VuFind/ILS/Driver/Factory.php
@@ -143,15 +143,15 @@ class Factory
     }
 
     /**
      * Factory for KohaRest driver.
      *
      * @param ServiceManager $sm Service manager.
      *
-     * @return KohaRest
+     * @return KohaILSDI
      */
-    public static function getKohaRest(ServiceManager $sm)
+    public static function getKohaILSDI(ServiceManager $sm)
     {
-        return new KohaRest($sm->getServiceLocator()->get('VuFind\DateConverter'));
+        return new KohaILSDI($sm->getServiceLocator()->get('VuFind\DateConverter'));
     }
 
     /**
@@ -143,15 +143,15 @@ class Factory
 
     /**
-     * Factory for KohaRest driver.
+     * Factory for KohaILSDI driver.
      *
      * @param ServiceManager $sm Service manager.
diff --git a/module/VuFind/src/VuFind/ILS/Driver/KohaRest.php b/module/VuFind/src/VuFind/ILS/Driver/KohaILSDI.php
similarity index 99%
rename from module/VuFind/src/VuFind/ILS/Driver/KohaRest.php
rename to module/VuFind/src/VuFind/ILS/Driver/KohaILSDI.php
index 0c7c7d2afd45b88c351bcd4626ba741276ef8b0a..067d5795ce5d94669313e2f83b6237ea61c6e7a1 100644
--- a/module/VuFind/src/VuFind/ILS/Driver/KohaRest.php
+++ b/module/VuFind/src/VuFind/ILS/Driver/KohaILSDI.php
@@ -1,6 +1,6 @@
 <?php
 /**
  * KohaRest ILS Driver
  *
  * PHP version 5
  *
@@ -33,9 +33,9 @@ use Zend\Log\LoggerInterface;
 use VuFind\Exception\Date as DateException;
 
 /**
  * VuFind Driver for Koha, using web APIs (version: 0.2)
  *
- * Last updated: 10/13/2015
+ * Last updated: 04/13/2016
  * Minimum Koha Version: 3.18.6
  *
  * @category VuFind2
@@ -45,7 +45,7 @@ use VuFind\Exception\Date as DateException;
  * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
  * @link     http://vufind.org/wiki/vufind2:building_an_ils_driver Wiki
  */
-class KohaRest extends \VuFind\ILS\Driver\AbstractBase implements
+class KohaILSDI extends \VuFind\ILS\Driver\AbstractBase implements
     \VuFindHttp\HttpServiceAwareInterface, \Zend\Log\LoggerAwareInterface
 {
     /**
@@ -176,7 +176,7 @@ class KohaRest extends \VuFind\ILS\Driver\AbstractBase implements
         $this->ilsBaseUrl = isset($this->config['Catalog']['url'])
             ? $this->config['Catalog']['url'] : "";
 
         // Default location defined in 'KohaRest.ini'
         $this->defaultLocation
             = isset($this->config['Holds']['defaultPickUpLocation'])
             ? $this->config['Holds']['defaultPickUpLocation'] : null;
@@ -494,7 +494,7 @@ class KohaRest extends \VuFind\ILS\Driver\AbstractBase implements
     /**
      * Get Default Pick Up Location
      *
      * Returns the default pick up location set in KohaRest.ini
      *
      * @param array $patron      Patron information returned by the patronLogin
      * method.
@@ -1,6 +1,6 @@
 <?php
 /**
- * KohaRest ILS Driver
+ * KohaILSDI ILS Driver
  *
  * PHP version 5
@@ -33,9 +33,9 @@ use Zend\Log\LoggerInterface;
 
 /**
- * VuFind Driver for Koha, using web APIs (version: 0.2)
+ * VuFind Driver for Koha, using web APIs (ILSDI) (version: 0.3)
  *
@@ -176,7 +176,7 @@ class KohaRest extends \VuFind\ILS\Driver\AbstractBase implements
             ? $this->config['Catalog']['url'] : "";
 
-        // Default location defined in 'KohaRest.ini'
+        // Default location defined in 'KohaILSDI.ini'
         $this->defaultLocation
             = isset($this->config['Holds']['defaultPickUpLocation'])
@@ -494,7 +494,7 @@ class KohaRest extends \VuFind\ILS\Driver\AbstractBase implements
      * Get Default Pick Up Location
      *
-     * Returns the default pick up location set in KohaRest.ini
+     * Returns the default pick up location set in KohaILSDI.ini
      *
      * @param array $patron      Patron information returned by the patronLogin